@@ -196,6 +196,10 @@ from presalytics.lib.widgets.matplotlib import MatplotlibFigure, MatplotlibRespo
 from presalytics.lib.widgets.d3 import (
     D3Widget
 )
+from presalytics.lib.widgets.chart import ChartWidget
+from presalytics.lib.widgets.data_table import DataTableWidget
+from presalytics.lib.widgets.url import UrlWidget
+from presalytics.lib.widgets.markdown import MarkdownWidget
 from presalytics.lib.widgets.ooxml import (
     OoxmlWidgetBase,
     OoxmlFileWidget, 
@@ -223,6 +227,7 @@ from presalytics.lib.widgets.ooxml_editors import (
 )
 
 
+
 __all__ = [
     'CONFIG',
     'COMPONENTS',
@@ -238,6 +243,9 @@ __all__ = [
     'OoxmlWidgetBase',
     'OoxmlEditorWidget',
     'D3Widget',
+    'ChartWidget',
+    'DataTableWidget',
+    'UrlWidget',
     'ChartUpdaterWidget',
     'TableUpdaterWidget',
     'XmlTransformBase',
